==> libgoose-0.0.1.tar.gz: libgoose-0.0.1/src/statfn.h <==
// This is -*- C++ -*-
// $Id: statfn.h,v 1.2 1998/08/19 16:53:21 hp Exp $

/* statfn.h
 *
 * Copyright (C) 1998 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@emccta.com>.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifndef _INC_STATFN_H
#define _INC_STATFN_H

double normal_cdf(double);
double inverse_normal_cdf(double);
double log_gamma(double);
double incomplete_gamma(double a,double x);
double incomplete_beta(double a,double b,double x);

double beta_function(double z, double w);
double log_factorial(double x);
double poisson_cdf(double k, double x);
double chi_square_cdf(double chi2, double df);
double students_cdf(double t, double df);
double F_cdf(double f, double df1, double df2);

#endif // _INC_STATFN_H

// $Id: statfn.h,v 1.2 1998/08/19 16:53:21 hp Exp $

==> libgoose-0.0.2.tar.gz: libgoose-0.0.2/src/statfn.h <==
// This is -*- C++ -*-
// $Id: statfn.h,v 1.4 1998/09/14 04:48:38 trow Exp $

/* statfn.h
 *
 * Copyright (C) 1998 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@emccta.com>.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifndef _INC_STATFN_H
#define _INC_STATFN_H


double factorial(int n);
double log_factorial(int n);
double choose(int n, int k);
double log_choose(int n, int k);

double log_gamma(double);
double incomplete_gamma(double a,double x);

double incomplete_beta(double a,double b,double x);
double log_beta_function(double z, double w);
double beta_function(double z, double w);

double normal_cdf(double);
double inv_normal_cdf(double);

double poisson_cdf(double k, double x);

double chi_square_cdf(double chi2, double df);
double inv_chi_square_cdf(double p, double df);

double students_cdf(double t, double df);
double inv_students_cdf(double p, double df);

double F_cdf(double f, double df1, double df2);

double inv_gamma_cdf(double p, double alpha, double scale);

#endif // _INC_STATFN_H

// $Id: statfn.h,v 1.4 1998/09/14 04:48:38 trow Exp $
